@@ -7,8 +7,7 @@
 #' gists("minepublic")[[29]] %>% delete()
 #' }
 
-delete <- function(gist, ...)
-{
+delete <- function(gist, ...) {
   gist <- as.gist(gist)
   res <- gist_DELETE(paste0(ghbase(), '/gists/', gist$id), auth = gist_auth(), headers = ghead(), ...)
   stop_for_status(res)
